..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Objectives
----------

-  To understand what a tree data structure is and how it is used.

-  To see how trees can be used to implement a map data structure.

-  To implement trees using a list.

-  To implement trees using classes and references.

-  To implement trees as a recursive data structure.

-  To implement a priority queue using a heap.

